==> php-residence_0.3.tar.gz: php-residence/includes/funzioni_mysql.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

#Funzioni per usare il database MYSQL

ignore_user_abort(1);

# variabili per le differenze nella sintassi delle query
$ILIKE = "LIKE";
$LIKE = "LIKE BINARY";


function connetti_db($database,$host,$port,$user,$password,$estensione) {

if ($estensione == "SI") dl("mysql.so");
$numconnessione = mysql_pconnect ("$host:$port", "$user", "$password");
mysql_select_db($database);

return $numconnessione;

} # fine function connetti_db


function disconnetti_db($numconnessione) {

$risultato = mysql_close($numconnessione);
return $risultato;

} # fine function disconnetti_db


function esegui_query($query,$silenzio = "") {

$risultato = mysql_query($query);
if (!$risultato and !$silenzio) echo "<br>ERROR IN: $query <br>".mysql_errno().": ".mysql_error()."<br>";

return $risultato;

} # fine function esegui_query


function risul_query($query,$riga,$colonna) {

$risultato = mysql_result($query,$riga,$colonna);
return $risultato;

} # fine function risul_query


function numlin_query($query) {

$risultato = mysql_num_rows($query);
return $risultato;

} # fine function numlin_query


function arraylin_query($query,$num) {

$risultato =  mysql_fetch_row($query);
return $risultato;

} # fine function arraylin_query


function numcampi_query($query) {

$risultato = mysql_num_fields($query);
return $risultato;

} # fine function numcampi_query


function nomecampo_query($query,$num) {

$risultato = mysql_field_name($query,$num);
return $risultato;

} # fine function nomecampo_query


function tipocampo_query($query,$num) {

$risultato = mysql_field_type($query,$num);
return $risultato;

} # fine function tipocampo_query


function dimcampo_query($query,$num) {

$risultato = mysql_field_len($query,$num);
return $risultato;

} # fine function dimcampo_query


function lock_tabelle($tabelle,$altre_tab_usate = "") {

$lock_dir = "./dati/";
#for ($num1 = 0 ; $num1 < count($tabelle); $num1++) {
#$lista_tabelle .= $tabelle[$num1]." write,";
#} # fine for $num1
#if (is_array($altre_tab_usate)) {
#for ($num1 = 0 ; $num1 < count($altre_tab_usate); $num1++) {
#$lista_tabelle .= $altre_tab_usate[$num1]." read,";
#} # fine for $num1
#} # fine if (is_array($altre_tab_usate))
#$lista_tabelle = substr($lista_tabelle,0,-1);
#$risultato = mysql_query("lock tables $lista_tabelle");
#if (!$risultato) echo "<br>ERROR IN: lock tables $lista_tabelle<br>".mysql_errno().": ".mysql_error()."<br>";

if (is_array($tabelle)) $num_tabelle = count($tabelle);
else $num_tabelle = 0;
if (is_array($altre_tab_usate)) $num_altre_tab_usate = count($altre_tab_usate);
else $num_altre_tab_usate = 0;
for ($num1 = 0 ; $num1 < $num_tabelle; $num1++) {
#if (!$tabelle[$num1]) echo "<br>ERROR: no tab lock $num1<br>";
$tabelle_lock[$num1] = fopen($lock_dir."tab_".$tabelle[$num1].".lock","w+");
flock($tabelle_lock[$num1],2);
} # fine for $num1
for ($num1 = $num_tabelle ; $num1 < ($num_tabelle+$num_altre_tab_usate); $num1++) {
#if (!$altre_tab_usate[($num1-$num_tabelle)]) echo "<br>ERROR: no altre_tab lock $num1<br>";
$tabelle_lock[$num1] = fopen($lock_dir."tab_".$altre_tab_usate[($num1-$num_tabelle)].".lock","w+");
flock($tabelle_lock[$num1],1);
} # fine for $num1
return $tabelle_lock;

} # fine function lock_tabelle


function unlock_tabelle($tabelle_lock,$azione = "") {

#$risultato = mysql_query("unlock tables");

for ($num1 = (count($tabelle_lock)-1) ; $num1 >= 0; $num1--) {
flock($tabelle_lock[$num1],3);
fclose($tabelle_lock[$num1]);
} # fine for $num1

} # fine function unlock_tabelle


function ini_controllo_db($tabella_controllata) {

$nuova_tableprenota = $tabella_controllata."_prova";
include ("./includes/crea_nuova_tableprenota.php");
$risultato = mysql_query("insert into $nuova_tableprenota select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna from $tabella_controllata");
if (!$risultato and !$silenzio) echo "<br>ERROR IN: insert into $nuova_tableprenota select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna from $tabella_controllata <br>".mysql_errno().": ".mysql_error()."<br>";
return $nuova_tableprenota;

} # fine function ini_controllo_db


function fine_controllo_db($azione,$tabella_controllata,$tabella_controllata_prova,$cambia,$id_cambiato,$val_cambiato,$tabelle_lock) {

if ($azione == "esegui") {
for ($num1 = 0 ; $num1 < $cambia["numero"] ; $num1 = $num1 + 1) {
mysql_query("update $tabella_controllata set ".$cambia["campo"]." = '".$val_cambiato[$num1]."' where ".$cambia["id"]." = '".$id_cambiato[$num1]."'");
} # fine for $num1
if ($cambia["linea_intera"]) {
$linea_vera = mysql_query("select * from $tabella_controllata where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
$linea_vera = mysql_fetch_array ($linea_vera,MYSQL_ASSOC);
$linea_prova = mysql_query("select * from $tabella_controllata_prova where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
$linea_prova = mysql_fetch_array ($linea_prova,MYSQL_ASSOC);
reset($linea_prova);
for ($num1 = 0 ; $num1 < count($linea_prova); $num1++) {
$nome_campo = key($linea_prova);
$val_campo_vero = $linea_vera["$nome_campo"];
$val_campo_prova = $linea_prova["$nome_campo"];
if ($val_campo_prova != $val_campo_vero) {
esegui_query("update $tabella_controllata set ".$nome_campo." = '".$val_campo_prova."' where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
} # fine if ($val_campo_prova != $val_campo_vero)
next($linea_prova);
} # fine for $num1
} # fine if ($cambia["linea_intera"])
} # fine if ($azione == "esegui")
mysql_query("drop table $tabella_controllata_prova");
if ($azione == "rollback") unlock_tabelle($tabelle_lock);

} # fine function fine_controllo_db



?>

==> php-residence_0.4.3.tar.gz: php-residence/includes/funzioni_mysql.php <==
<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

#Funzioni per usare il database MYSQL

ignore_user_abort(1);

# variabili per le differenze nella sintassi delle query
#global $ILIKE,$LIKE;
$ILIKE = "LIKE";
$LIKE = "LIKE BINARY";


function connetti_db($database,$host,$port,$user,$password,$estensione) {

if ($estensione == "SI") dl("mysql.so");
$numconnessione = mysql_pconnect ("$host:$port", "$user", "$password");
mysql_select_db($database);

return $numconnessione;

} # fine function connetti_db


function disconnetti_db($numconnessione) {

$risultato = mysql_close($numconnessione);
return $risultato;

} # fine function disconnetti_db


function esegui_query($query,$silenzio = "") {

$risultato = mysql_query($query);
if (!$risultato and !$silenzio) echo "<br>ERROR IN: $query <br>".mysql_errno().": ".mysql_error()."<br>";

return $risultato;

} # fine function esegui_query


function risul_query($query,$riga,$colonna) {

$risultato = mysql_result($query,$riga,$colonna);
#if (!$risultato) echo "<br>Nessun risultato in riga $riga colonna $colonna<br>";

return $risultato;

} # fine function risul_query


function numlin_query($query) {

$risultato = mysql_num_rows($query);
return $risultato;

} # fine function numlin_query


function arraylin_query($query,$num) {

$risultato =  mysql_fetch_row($query);
return $risultato;

} # fine function arraylin_query


function numcampi_query($query) {

$risultato = mysql_num_fields($query);
return $risultato;

} # fine function numcampi_query


function nomecampo_query($query,$num) {

$risultato = mysql_field_name($query,$num);
return $risultato;

} # fine function nomecampo_query


function tipocampo_query($query,$num) {

$risultato = mysql_field_type($query,$num);
return $risultato;

} # fine function tipocampo_query


function dimcampo_query($query,$num) {

$risultato = mysql_field_len($query,$num);
return $risultato;

} # fine function dimcampo_query


function lock_tabelle($tabelle,$altre_tab_usate = "",$lock_dir = "./dati/") {

if (@is_array($tabelle)) {
for ($num1 = 0 ; $num1 < count($tabelle); $num1++) {
$lista_tabelle .= $tabelle[$num1]." write,";
} # fine for $num1
} # fine if (@is_array($tabelle))
if (@is_array($altre_tab_usate)) {
for ($num1 = 0 ; $num1 < count($altre_tab_usate); $num1++) {
$lista_tabelle .= $altre_tab_usate[$num1]." read,";
} # fine for $num1
} # fine if (@is_array($altre_tab_usate))
$lista_tabelle = substr($lista_tabelle,0,-1);
$risultato = mysql_query("lock tables $lista_tabelle");
if (!$risultato) echo "<br>ERROR IN: lock tables $lista_tabelle<br>".mysql_errno().": ".mysql_error()."<br>";

/*
if (is_array($tabelle)) $num_tabelle = count($tabelle);
else $num_tabelle = 0;
if (is_array($altre_tab_usate)) $num_altre_tab_usate = count($altre_tab_usate);
else $num_altre_tab_usate = 0;
for ($num1 = 0 ; $num1 < $num_tabelle; $num1++) {
#if (!$tabelle[$num1]) echo "<br>ERROR: no tab lock $num1<br>";
$tabelle_lock[$num1] = fopen($lock_dir."tab_".$tabelle[$num1].".lock","w+");
flock($tabelle_lock[$num1],2);
} # fine for $num1
for ($num1 = $num_tabelle ; $num1 < ($num_tabelle+$num_altre_tab_usate); $num1++) {
#if (!$altre_tab_usate[($num1-$num_tabelle)]) echo "<br>ERROR: no altre_tab lock $num1<br>";
$tabelle_lock[$num1] = fopen($lock_dir."tab_".$altre_tab_usate[($num1-$num_tabelle)].".lock","w+");
flock($tabelle_lock[$num1],1);
} # fine for $num1
return $tabelle_lock;
*/

} # fine function lock_tabelle


function unlock_tabelle($tabelle_lock,$azione = "") {

$risultato = mysql_query("unlock tables");

/*
for ($num1 = (count($tabelle_lock)-1) ; $num1 >= 0; $num1--) {
flock($tabelle_lock[$num1],3);
fclose($tabelle_lock[$num1]);
} # fine for $num1
*/

} # fine function unlock_tabelle


/*
function ini_controllo_db($tabella_controllata) {

$nuova_tableprenota = $tabella_controllata."_prova";
include ("./includes/crea_nuova_tableprenota.php");
$risultato = mysql_query("insert into $nuova_tableprenota select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna from $tabella_controllata");
if (!$risultato and !$silenzio) echo "<br>ERROR IN: insert into $nuova_tableprenota select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna from $tabella_controllata <br>".mysql_errno().": ".mysql_error()."<br>";
return $nuova_tableprenota;

} # fine function ini_controllo_db


function fine_controllo_db($azione,$tabella_controllata,$tabella_controllata_prova,$cambia,$id_cambiato,$val_cambiato,$tabelle_lock) {

if ($azione == "esegui") {
for ($num1 = 0 ; $num1 < $cambia["numero"] ; $num1 = $num1 + 1) {
mysql_query("update $tabella_controllata set ".$cambia["campo"]." = '".$val_cambiato[$num1]."' where ".$cambia["id"]." = '".$id_cambiato[$num1]."'");
} # fine for $num1
if ($cambia["linea_intera"]) {
$linea_vera = mysql_query("select * from $tabella_controllata where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
$linea_vera = mysql_fetch_array ($linea_vera,MYSQL_ASSOC);
$linea_prova = mysql_query("select * from $tabella_controllata_prova where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
$linea_prova = mysql_fetch_array ($linea_prova,MYSQL_ASSOC);
reset($linea_prova);
for ($num1 = 0 ; $num1 < count($linea_prova); $num1++) {
$nome_campo = key($linea_prova);
$val_campo_vero = $linea_vera["$nome_campo"];
$val_campo_prova = $linea_prova["$nome_campo"];
if ($val_campo_prova != $val_campo_vero) {
esegui_query("update $tabella_controllata set ".$nome_campo." = '".$val_campo_prova."' where ".$cambia["id"]." = '".$cambia["linea_intera"]."'");
} # fine if ($val_campo_prova != $val_campo_vero)
next($linea_prova);
} # fine for $num1
} # fine if ($cambia["linea_intera"])
} # fine if ($azione == "esegui")
mysql_query("drop table $tabella_controllata_prova");
if ($azione == "rollback") unlock_tabelle($tabelle_lock);

} # fine function fine_controllo_db
*/


?>
